@@ -7,7 +7,7 @@
 from __future__ import absolute_import, division
 from __future__ import print_function, unicode_literals
 
-from ._exporter import CellMLExporter
+from ._exporter import CellMLExporter, CellML1Exporter, CellML2Exporter
 from ._ewriter import CellMLExpressionWriter
 from ._importer import CellMLImporter, CellMLImporterError  # noqa
 
@@ -16,6 +16,7 @@ from ._importer import CellMLImporter, CellMLImporterError  # noqa
 NS_BQBIOL = 'http://biomodels.net/biology-qualifiers/'
 NS_CELLML_1_0 = 'http://www.cellml.org/cellml/1.0#'
 NS_CELLML_1_1 = 'http://www.cellml.org/cellml/1.1#'
+NS_CELLML_2_0 = 'http://www.cellml.org/cellml/2.0#'
 NS_CMETA = 'http://www.cellml.org/metadata/1.0#'
 NS_MATHML = 'http://www.w3.org/1998/Math/MathML'
 NS_OXMETA = 'https://chaste.comlab.ox.ac.uk/cellml/ns/oxford-metadata#'
@@ -39,6 +40,8 @@ def importers():
 # Exporters
 _exporters = {
     'cellml': CellMLExporter,
+    'cellml1': CellML1Exporter,
+    'cellml2': CellML2Exporter,
 }
 
 
