@@ -9,6 +9,7 @@ from __future__ import print_function, unicode_literals
 
 import collections
 import re
+import warnings
 
 import myokit
 
@@ -101,10 +102,10 @@ def create_unit_name(unit):
         name, multiplier = name, ''
 
     # Could also be because it's g*m/mol^2
-    # (Exponents are integers, so don't need to deal with floats here)
     name = name.replace('^', '')
     name = name.replace('/', '_per_')
     name = name.replace('*', '_')
+    name = name.replace('.', '_dot_')
 
     # Remove "1_" from "1_per_mV"
     if name[:2] == '1_':
@@ -272,7 +273,7 @@ class Component(AnnotatableElement):
     def __str__(self):
         return 'Component[@name="' + self._name + '"]'
 
-    def _validate(self, warnings):
+    def _validate(self):
         """
         Validates this component, raising a :class:`CellMLError` if any errors
         are found.
@@ -307,7 +308,6 @@ class Model(AnnotatableElement):
     - Imports are not supported.
     - Reset rules are not supported.
     - Using variables in ``initial_value`` attributes is not supported.
-    - Units with a non-integer exponent are not supported.
     - Defining new base units is not supported.
     - All equations must be of the form ``x = ...`` or ``dx/dt = ...``.
     - Models that take derivatives with respect to more than one variable are
@@ -984,15 +984,11 @@ class Model(AnnotatableElement):
         """
         Validates this model, raising a :class:`CellMLError` if an errors are
         found.
-
-        Returns a list of warnings generated during validation.
         """
-        # Warnings
-        warnings = []
 
         # Validate components and variables
         for c in self._components.values():
-            c._validate(warnings)
+            c._validate()
 
         # Collect all connected variable sets for validation
         csets = set()
@@ -1004,18 +1000,18 @@ class Model(AnnotatableElement):
         free = set()
         for cset in csets:
             # Validate cset
-            cset._validate(warnings)
+            cset._validate()
 
             # Check if free
             if cset.equation() is None and cset.initial_value() is None:
                 free.add(cset)
                 if self._voi not in cset:
                     for var in cset:
-                        warnings.append('No value set for ' + str(var) + '.')
+                        warnings.warn('No value set for ' + str(var) + '.')
 
         # Check that there's at most one free variable.
         if len(free) > 1:
-            warnings.append('More than one variable does not have a value.')
+            warnings.warn('More than one variable does not have a value.')
 
         # Check that the variable of integration is a free variable
         voi = self.variable_of_integration()
@@ -1036,9 +1032,6 @@ class Model(AnnotatableElement):
                     msg += 'initial value (set by ' + str(var) + ').'
             raise CellMLError(msg)
 
-        # Return warnings
-        return warnings
-
     def variable_of_integration(self):
         """
         Returns the model's variable of integration, if any.
@@ -1217,13 +1210,8 @@ class Units(object):
                     + str(multiplier) + '"')
             e = float(exponent)
 
-            # Only integers are supported by Myokit
-            if not myokit._feq(e, int(e)):
-                raise CellMLError(
-                    'Non-integer unit exponents are not supported.')
-
             # Apply exponent to unit
-            unit **= int(e)
+            unit **= e
 
         # Handle multiplier
         if multiplier is not None:
@@ -1776,7 +1764,7 @@ class ConnectedVariableSet(object):
         self._initial_value = value
         self._initial_value_variable = None if value is None else variable
 
-    def _validate(self, warnings):
+    def _validate(self):
         """
         Validates this variable set, raising a CellMLError if errors are found.
         """
