@@ -8,7 +8,7 @@ from __future__ import absolute_import, division
 from __future__ import print_function, unicode_literals
 
 import myokit
-from myokit.mxml import split
+from myokit.formats.xml import split
 
 
 def parse_mathml_string(s):
@@ -91,7 +91,8 @@ class MathMLParser(object):
     Literals and references
 
     ``<ci>``
-        Becomes a :class:`myokit.Name`.
+        Is converted to a :class:`myokit.Name` by passing the contents of the
+        ``ci`` tag to the ``name_factory``.
     ``<diff>`` (with ``<bvar>`` and ``<degree>``)
         Becomes a :class:`myokit.Derivative`. Only first-order derivatives are
         supported. To check if the derivatives are all time-derivatives, the
@@ -100,6 +101,10 @@ class MathMLParser(object):
         Becomes a :class:`myokit.Number`. To process units which may be present
         in the tag's attributes (esp. in CellML) the number post-processing
         function can be used.
+    ``<csymbol>``
+        Is converted to a :class:`myokit.Name` by passing the contents of its
+        ``definitionURL`` to the ``name_factory``. Note that ``csymbols``
+        representing operators or functions are not supported.
 
     Algebra
 
@@ -305,6 +310,9 @@ class MathMLParser(object):
         elif name == 'cn':
             return self._parse_number(element)
 
+        elif name == 'csymbol':
+            return self._parse_symbol(element)
+
         # Constants
         elif name == 'pi':
             return self._const('3.14159265358979323846')
@@ -938,12 +946,31 @@ class MathMLParser(object):
         Parses a ``<ci>`` element and returns a :class:`myokit.Name` created by
         the name factory.
         """
-
         if element.text is None:
             raise MathMLError(
                 '<ci> element must contain a variable name.', element)
+
+        symbol = element.text.strip()
         try:
-            return self._vfac(element.text.strip(), element)
+            return self._vfac(symbol, element)
         except Exception as e:
             raise MathMLError('Unable to create Name: ' + str(e), element)
 
+    def _parse_symbol(self, element):
+        """
+        Parses only ``<csymbol>`` elements that represent special variables
+        and returns a :class:`myokit.Name` created by the name factory.
+        """
+        symbol = element.get('definitionURL')
+        if symbol is None:
+            raise MathMLError(
+                '<csymbol> element must contain a definitionURL attribute.',
+                element)
+
+        symbol = symbol.strip()
+        try:
+            return self._vfac(symbol, element)
+        except Exception as e:
+            raise MathMLError(
+                'Unable to create Name from csymbol: ' + str(e), element)
+
