@@ -77,11 +77,11 @@ if pyqt5:
         # was already set.
         pass
     else:   # pragma: no cover
-        try:
+        # The method below was deprecated by matplotlib version 2.2, released
+        # in 2018. So probably fine to remove this (and similar) after 2023
+        v = [int(x) for x in matplotlib.__version__.split('.')]
+        if v[0] < 3 and v[1] < 3:
             matplotlib.rcParams['backend.qt5'] = 'PyQt5'
-        except KeyError:
-            # This is no longer allowed / necessary in matplotlib 3.1.0
-            pass
     import matplotlib.backends.backend_qt5agg as matplotlib_backend
 
     # Set backend variables
@@ -100,15 +100,13 @@ elif pyside2:
     try:
         matplotlib.use('Qt5Agg')
     except ImportError:
-        # In matplotlib 3.7.0 this raises ImportErrors if a previous backend
+        # In matplotlib 3.3.0 this raises ImportErrors if a previous backend
         # was already set.
         pass
     else:   # pragma: no cover
-        try:
+        v = [int(x) for x in matplotlib.__version__.split('.')]
+        if v[0] < 3 and v[1] < 3:
             matplotlib.rcParams['backend.qt5'] = 'PySide2'
-        except KeyError:
-            # This is no longer allowed / necessary in matplotlib 3.1.0
-            pass
     import matplotlib.backends.backend_qt5agg as matplotlib_backend  # noqa
 
     # Set backend variables
@@ -196,15 +194,13 @@ elif pyqt4:
     try:
         matplotlib.use('Qt4Agg')
     except ImportError:
-        # In matplotlib 3.7.0 this raises ImportErrors if a previous backend
+        # In matplotlib 3.3.0 this raises ImportErrors if a previous backend
         # was already set.
         pass
     else:   # pragma: no cover
-        try:
+        v = [int(x) for x in matplotlib.__version__.split('.')]
+        if v[0] < 3 and v[1] < 3:
             matplotlib.rcParams['backend.qt4'] = 'PyQt4'
-        except KeyError:
-            # This is no longer allowed / necessary in matplotlib 3.1.0
-            pass
     import matplotlib.backends.backend_qt4agg as matplotlib_backend
 
     # Set backend variables
@@ -286,15 +282,13 @@ elif pyside:
     try:
         matplotlib.use('Qt4Agg')
     except ImportError:
-        # In matplotlib 3.7.0 this raises ImportErrors if a previous backend
+        # In matplotlib 3.3.0 this raises ImportErrors if a previous backend
         # was already set.
         pass
     else:   # pragma: no cover
-        try:
+        v = [int(x) for x in matplotlib.__version__.split('.')]
+        if v[0] < 3 and v[1] < 3:
             matplotlib.rcParams['backend.qt4'] = 'PySide'
-        except KeyError:
-            # This is no longer allowed / necessary in matplotlib 3.1.0
-            pass
     import matplotlib.backends.backend_qt4agg as matplotlib_backend  # noqa
 
     # Set backend variables
