@@ -14,6 +14,7 @@ import os
 import sys
 import textwrap
 import traceback
+import warnings
 
 # Myokit
 import myokit
@@ -35,7 +36,6 @@ from . import vargrapher
 # Matplotlib.pyplot must be imported _after_ myokit.gui has set the backend
 import matplotlib
 matplotlib.interactive(True)        # Allows plt.show()
-import matplotlib.pyplot as plt     # noqa -- Make flake8 ignore this line
 
 # ConfigParser in Python 2 and 3
 try:
@@ -386,6 +386,7 @@ class MyokitIDE(myokit.gui.MyokitApplication):
         """
         Displays a component dependency graph
         """
+        import matplotlib.pyplot as plt
         try:
             model = self.model(errors_in_console=True)
             if not model:
@@ -482,7 +483,6 @@ class MyokitIDE(myokit.gui.MyokitApplication):
                 return
 
             e = myokit.formats.exporter(name)
-            e.logger().log(e.info())
             if not e.supports_model():
                 raise Exception('Exporter does not support export of model')
 
@@ -494,20 +494,29 @@ class MyokitIDE(myokit.gui.MyokitApplication):
             if not filename:
                 return
 
-            try:
-                if name in ('cellml1', 'cellml2'):
-                    p = self.protocol(errors_in_console=True)
-                    if p is False:
-                        p = None
-                    e.model(filename, m, p)
-                else:
-                    e.model(filename, m)
+            ex = None
+            with warnings.catch_warnings(record=True) as ws:
+                try:
+                    if name in ('cellml1', 'cellml2'):
+                        p = self.protocol(errors_in_console=True)
+                        if p is False:
+                            p = None
+                        e.model(filename, m, p)
+                    else:
+                        e.model(filename, m)
+                except myokit.ExportError as ex:
+                    pass
+            for w in ws:
+                self._console.write('Warning: ' + str(w.message))
 
-                msg = 'Export successful.'
-            except myokit.ExportError:
-                msg = 'Export failed.'
-
-            self._console.write(msg + '\n' + e.logger().text())
+            if ex is None:
+                self._console.write('Export successful.')
+                info = e.post_export_info()
+                if info:
+                    self._console.write(info)
+            else:
+                self._console.write('Export failed.')
+                self._console.write(str(ex))
 
         except Exception:
             self.show_exception()
@@ -530,22 +539,36 @@ class MyokitIDE(myokit.gui.MyokitApplication):
             p = self.protocol(errors_in_console=True)
             if p is False:
                 return
+
             # Create exporter & test compatibility
             e = myokit.formats.exporter(name)
             if not e.supports_runnable():
                 raise Exception('Exporter does not support export of runnable')
+
             # Select dir
             path = QtWidgets.QFileDialog.getSaveFileName(
                 self, 'Create directory', self._path)[0]
             if not path:
                 return
-            try:
-                e.runnable(path, m, p)
-                msg = 'Export successful.'
-                e.logger().log(e.info())
-            except myokit.ExportError:
-                msg = 'Export failed.'
-            self._console.write(msg + '\n' + e.logger().text())
+
+            ex = None
+            with warnings.catch_warnings(record=True) as ws:
+                try:
+                    e.runnable(path, m, p)
+                except myokit.ExportError as ex:
+                    pass
+            for w in ws:
+                self._console.write('Warning: ' + str(w.message))
+
+            if ex is None:
+                self._console.write('Export successful.')
+                info = e.post_export_info()
+                if info:
+                    self._console.write(info)
+            else:
+                self._console.write('Export failed.')
+                self._console.write(str(ex))
+
         except Exception:
             self.show_exception()
 
@@ -588,30 +611,46 @@ class MyokitIDE(myokit.gui.MyokitApplication):
                 self, 'Open ABF file', self._path, filter=FILTER_ABF)[0]
             if not filename:
                 return
-            # Load file
+
+            # Create importer
             i = myokit.formats.importer('abf')
-            try:
-                protocol = i.protocol(filename)
-                # Import okay, update interface
-                self.new_file()
-                self._protocol_editor.setPlainText(protocol.code())
-                self._console.write(
-                    'Protocol imported successfully.\n' + i.logger().text())
-                # Set working directory to file's path
-                self._path = os.path.dirname(filename)
-                os.chdir(self._path)
-                # Save settings file
+
+            # Import
+            exception = None
+            with warnings.catch_warnings(record=True) as ws:
                 try:
-                    self.save_config()
-                except Exception:
-                    pass
-                # Update interface
-                self._tool_save.setEnabled(True)
-                self.update_window_title()
-            except myokit.ImportError:
-                self._console.write(
-                    'Protocol import failed.\n' + i.logger().text())
+                    protocol = i.protocol(filename)
+                except myokit.ImportError as ex:
+                    exception = ex
+            for w in ws:
+                self._console.write('Warning: ' + str(w.message))
+
+            # Handle failure
+            if exception is not None:
+                self._console.write('Protocol import failed.')
+                self._console.write(str(exception))
                 self.statusBar().showMessage('Protocol import failed.')
+                return
+
+            # Import okay, update interface
+            self.new_file()
+            self._protocol_editor.setPlainText(protocol.code())
+            self._console.write('Protocol imported successfully.')
+
+            # Set working directory to file's path
+            self._path = os.path.dirname(filename)
+            os.chdir(self._path)
+
+            # Save settings file
+            try:
+                self.save_config()
+            except Exception:
+                pass
+
+            # Update interface
+            self._tool_save.setEnabled(True)
+            self.update_window_title()
+
         except Exception:
             self.show_exception()
 
@@ -641,49 +680,52 @@ class MyokitIDE(myokit.gui.MyokitApplication):
 
             # Load file
             i = myokit.formats.importer(name)
-            try:
-                # Import the model
-                model = i.model(filename)
 
-                # Try to split off protocol
-                protocol = myokit.lib.guess.remove_embedded_protocol(model)
-
-                # No protocol? Then create one
-                if protocol is None:
-                    protocol = myokit.default_protocol(model)
-
-                # Get default script
-                script = myokit.default_script(model)
-
-                # Import okay, update interface
-                self.new_file()
-                self._model_editor.setPlainText(model.code())
-                self._protocol_editor.setPlainText(protocol.code())
-                self._script_editor.setPlainText(script)
-
-                # Write log to console
-                i.logger().log_warnings()
-                self._console.write(
-                    'Model imported successfully.\n' + i.logger().text())
-
-                # Save settings file
+            # Import the model
+            exception = None
+            with warnings.catch_warnings(record=True) as ws:
                 try:
-                    self.save_config()
-                except Exception:
-                    pass
+                    model = i.model(filename)
+                except myokit.ImportError as e:
+                    exception = e
+            for w in ws:
+                self._console.write('Warning: ' + str(w.message))
 
-                # Update interface
-                self._tool_save.setEnabled(True)
-                self.update_window_title()
-
-            except myokit.ImportError as e:
-
-                # Write output to console
-                i.logger().log_warnings()
-                self._console.write(
-                    'Model import failed.\n' + i.logger().text()
-                    + '\n\nModel import failed.\n' + str(e))
+            # Import failed?
+            if exception is not None:
+                self._console.write('Model import failed.')
+                self._console.write(str(exception))
                 self.statusBar().showMessage('Model import failed.')
+                return
+
+            # Try to split off protocol
+            protocol = myokit.lib.guess.remove_embedded_protocol(model)
+
+            # No protocol? Then create one
+            if protocol is None:
+                protocol = myokit.default_protocol(model)
+
+            # Get default script
+            script = myokit.default_script(model)
+
+            # Import okay, update interface
+            self.new_file()
+            self._model_editor.setPlainText(model.code())
+            self._protocol_editor.setPlainText(protocol.code())
+            self._script_editor.setPlainText(script)
+
+            # Write log to console
+            self._console.write('Model imported successfully.')
+
+            # Save settings file
+            try:
+                self.save_config()
+            except Exception:
+                pass
+
+            # Update interface
+            self._tool_save.setEnabled(True)
+            self.update_window_title()
 
         except Exception:
             self.show_exception()
@@ -822,6 +864,7 @@ class MyokitIDE(myokit.gui.MyokitApplication):
         """
         Displays a preview of the current protocol.
         """
+        import matplotlib.pyplot as plt
         try:
             p = self.protocol(errors_in_console=True)
             if p is False:
@@ -990,6 +1033,7 @@ class MyokitIDE(myokit.gui.MyokitApplication):
         """
         Displays a state dependency matrix.
         """
+        import matplotlib.pyplot as plt
         try:
             # Validate model
             model = self.model(errors_in_console=True)
@@ -1030,8 +1074,7 @@ class MyokitIDE(myokit.gui.MyokitApplication):
         Validates the model and, if the model is valid, the protocol.
         """
         try:
-            if not self.model(console=True):
-                return
+            self.model(console=True)
             self.protocol(console=True)
         except Exception:
             self.show_exception()
@@ -1062,6 +1105,7 @@ class MyokitIDE(myokit.gui.MyokitApplication):
         """
         Displays a variable dependency graph
         """
+        import matplotlib.pyplot as plt
         try:
             model = self.model(errors_in_console=True)
             if not model:
